@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# 2011 Steven Armstrong (steven-cdist at armstrong.cc)
+# 2011-2017 Steven Armstrong (steven-cdist at armstrong.cc)
 # 2012-2015 Nico Schottelius (nico-cdist at schottelius.org)
 #
 # This file is part of cdist.
@@ -23,6 +23,7 @@
 import getpass
 import os
 import shutil
+import logging
 
 import cdist
 from cdist import core
@@ -46,6 +47,7 @@ class CodeTestCase(test.CdistTestCase):
 
         self.local = local.Local(
             target_host=self.target_host,
+            target_host_tags=self.target_host_tags,
             base_root_path=self.host_base_path,
             host_dir_name=self.hostdir,
             exec_path=cdist.test.cdist_exec_path,
@@ -59,7 +61,9 @@ class CodeTestCase(test.CdistTestCase):
             target_host=self.target_host,
             remote_exec=remote_exec,
             remote_copy=remote_copy,
-            base_path=self.remote_dir)
+            base_path=self.remote_dir,
+            stdout_base_path=self.local.stdout_base_path,
+            stderr_base_path=self.local.stderr_base_path)
         self.remote.create_files_dirs()
 
         self.code = code.Code(self.target_host, self.local, self.remote)
@@ -97,6 +101,11 @@ class CodeTestCase(test.CdistTestCase):
                          self.cdist_object.object_id)
         self.assertEqual(output_dict['__object_name'], self.cdist_object.name)
         self.assertEqual(output_dict['__files'], self.local.files_path)
+        self.assertEqual(output_dict['__target_host_tags'],
+                         self.local.target_host_tags)
+        self.assertEqual(output_dict['__cdist_log_level'],
+                         str(logging.WARNING))
+        self.assertEqual(output_dict['__cdist_log_level_name'], 'WARNING')
 
     def test_run_gencode_remote_environment(self):
         output_string = self.code.run_gencode_remote(self.cdist_object)
@@ -120,6 +129,11 @@ class CodeTestCase(test.CdistTestCase):
                          self.cdist_object.object_id)
         self.assertEqual(output_dict['__object_name'], self.cdist_object.name)
         self.assertEqual(output_dict['__files'], self.local.files_path)
+        self.assertEqual(output_dict['__target_host_tags'],
+                         self.local.target_host_tags)
+        self.assertEqual(output_dict['__cdist_log_level'],
+                         str(logging.WARNING))
+        self.assertEqual(output_dict['__cdist_log_level_name'], 'WARNING')
 
     def test_transfer_code_remote(self):
         self.cdist_object.code_remote = self.code.run_gencode_remote(
@@ -140,6 +154,7 @@ class CodeTestCase(test.CdistTestCase):
         self.code.transfer_code_remote(self.cdist_object)
         self.code.run_code_remote(self.cdist_object)
 
+
 if __name__ == '__main__':
     import unittest
     unittest.main()
